.. uwacan documentation master file, created by
   sphinx-quickstart on Tue Jul 30 15:29:15 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

####################
Uwacan documentation
####################

Welcome to the Underwater Acoustic Analysis toolbox for python.
This contains implementations of some analysis methods for underwater acoustics, with a focus on monitoring of noise for environmental impact.

**Some useful links**: :doc:`Installing <user/installing>` | `Source code <https://github.com/CarlAndersson/underwater-acoustic-analysis>`_ | `Issue tracker <https://github.com/CarlAndersson/underwater-acoustic-analysis/issues>`_

.. toctree::
   :maxdepth: 1

   User Guide <user/index>
   API Reference <reference/index>
